Module second

Module second 

Second

Examples:

let x = SecondAsStructF64(1.0); // One second of time

https://wikipedia.org/wiki/Second

The second unit is a unit of time.

It is a base unit in the International System of Units (SI).

The SI unit symbol is s.

The second is commonly understood as 1⁄60 of a minute. Analog clocks and watches often have sixty tick marks on their faces, representing seconds (and minutes), and a “second hand” to mark the passage of time in seconds. Digital clocks and watches often have a two-digit seconds counter.

The second is also part of several other units of measurement like metres per second for speed, metres per second per second for acceleration, and cycles per second for frequency.

Structs

SecondAsStructF32
SecondAsStructF64
SecondAsStructI8
SecondAsStructI16
SecondAsStructI32
SecondAsStructI64
SecondAsStructI128
SecondAsStructISize
SecondAsStructU8
SecondAsStructU16
SecondAsStructU32
SecondAsStructU64
SecondAsStructU128
SecondAsStructUSize

Type Aliases

SecondAsTypeF32
SecondAsTypeF64
SecondAsTypeI8
SecondAsTypeI16
SecondAsTypeI32
SecondAsTypeI64
SecondAsTypeI128
SecondAsTypeISize
SecondAsTypeU8
SecondAsTypeU16
SecondAsTypeU32
SecondAsTypeU64
SecondAsTypeU128
SecondAsTypeUSize